==> mono_2.6.7.orig.tar.gz: mono-2.6.7/mcs/class/corlib/System.Security.Permissions/CodeAccessSecurityAttribute.cs <==
// 
// System.Security.Permissions.SecurityPermissionAttribute.cs 
//
// Author:         Nick Drochak, ndrochak@gol.com
// Created:        2002-01-06 
//
// Copyright (C) 2001 Nick Drochak, All Rights Reserved
// Copyright (C) 2004-2006 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System.Runtime.InteropServices;

namespace System.Security.Permissions {

#if NET_2_1
	[Obsolete ("CAS support is not available with Silverlight applications.")]
#endif
#if NET_2_0
	[ComVisible (true)]
#endif
	[AttributeUsage(
		AttributeTargets.Assembly 
		| AttributeTargets.Class 
		| AttributeTargets.Struct 
		| AttributeTargets.Constructor 
		| AttributeTargets.Method, 
		AllowMultiple=true, 
		Inherited=false)
	]
	[Serializable]
	public abstract class CodeAccessSecurityAttribute : SecurityAttribute {

#if NET_2_0
		protected CodeAccessSecurityAttribute (SecurityAction action) 
#else
		public CodeAccessSecurityAttribute (SecurityAction action) 
#endif
			: base (action)
		{
		}
	}
}

==> mono_3.2.8+dfsg.orig.tar.gz: mono-3.2.8+dfsg/mcs/class/corlib/System.Security.Permissions/CodeAccessSecurityAttribute.cs <==
// 
// System.Security.Permissions.SecurityPermissionAttribute.cs 
//
// Author:         Nick Drochak, ndrochak@gol.com
// Created:        2002-01-06 
//
// Copyright (C) 2001 Nick Drochak, All Rights Reserved
// Copyright (C) 2004-2006 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System.Runtime.InteropServices;

namespace System.Security.Permissions {

#if NET_2_1 && !MONOTOUCH
	[Obsolete ("CAS support is not available with Silverlight applications.")]
#endif
	[ComVisible (true)]
	[AttributeUsage(
		AttributeTargets.Assembly 
		| AttributeTargets.Class 
		| AttributeTargets.Struct 
		| AttributeTargets.Constructor 
		| AttributeTargets.Method, 
		AllowMultiple=true, 
		Inherited=false)
	]
	[Serializable]
	public abstract class CodeAccessSecurityAttribute : SecurityAttribute {

		protected CodeAccessSecurityAttribute (SecurityAction action) 
			: base (action)
		{
		}
	}
}
